import org.videolan.jvlc.JVLC;
import org.videolan.jvlc.MediaDescriptor;
import org.videolan.jvlc.MediaPlayer;
import org.videolan.jvlc.Video;


public class MovieSnap {
	
	private static final String VERSION = "0.1";
	
	private static void usage() {
		System.out.println("parameter: ");
		System.out.println("   url: filesource (needed argument)");
		System.out.println("   snapshotSize: size of snapshot image (128)");
		System.out.println("   picsPerMovie: get # of snapshot per file (1500)");				
		System.out.println("   snapshotDir: path where to save the snapshots");
		System.out.println("   noVerbose: disable vlc verbose messages");
		System.out.println("   vlcPluginPath: path to vlc plugin directory");
		System.out.println("   snapshotPrefix: prefix for snapshot files");
		System.out.println("   noVideoOut: disable video output");
		System.out.println("   crop: crop video, aspect ration 1:1");
		System.out.println("   noSnapshotPreview: do not display snapshot preview");		
		System.out.println();
		System.out.println("example:");
		System.out.println("   java -classpath .;%classpath%;jvlc-core-1.0.0-SNAPSHOT.jar;jna.jar MovieSnap snapshotSize=256 noVerbose noVideoOut crop vlcPluginPath=c:\\Programme\\VideoLAN\\VLC\\plugins url=c:\\movie.avi");
		System.exit(0);
	}
	
	/**
	 * @param args
	 * @throws InterruptedException 
	 */
	public static void main(String[] args) throws InterruptedException {
	    String media = "";
        String snapshotDir = "";
        String vlcVout = "";
        String vlcCrop = "";
        String vlcVerbose = "-vvv";
        String vlcPluginPath="c:\\Programme\\VideoLAN\\VLC\\plugins";
        String vlcSnapshotPreview="";
        String snapshotPrefix = "S_";
        int snapshotSize=128;
        float picsPerMovie = 1500;
        boolean urlParameterExists=false;

        System.out.println("#neophob.com MovieSnap v"+VERSION);

        if (args.length < 1) {
        	usage();
        }
        
        for (String s: args) {
        	//System.out.println("PARAMETER: "+s);        	
        	if (s.startsWith("snapshotSize")) {
        		snapshotSize = Integer.parseInt(s.split("=")[1]);
        	}
        	if (s.startsWith("snapshotPrefix")) {
        		snapshotPrefix = s.split("=")[1];
        	}        	
        	if (s.startsWith("picsPerMovie")) {
        		picsPerMovie = Float.parseFloat(s.split("=")[1]);
        	}
        	if (s.startsWith("url")) {
        		media = s.split("=")[1];
        		urlParameterExists = true;
        	}
        	if (s.startsWith("snapshotDir")) {
        		snapshotDir = s.split("=")[1];
        	}
        	if (s.startsWith("noVerbose")) {
        		vlcVerbose = ""; 
        	}        	
        	if (s.startsWith("vlcPluginPath")) {
        		vlcPluginPath = s.split("=")[1];
        	}        	       
        	if (s.startsWith("noVideoOut")) {
        		vlcVout="--vout=dummy";
        	}        	       
        	if (s.startsWith("crop")) {
        		vlcCrop="--crop=1:1";
        	}
        	if (s.startsWith("noSnapshotPreview")) {
        		vlcSnapshotPreview="--no-snapshot-preview";
        	}
        	
        }
        
        if (!urlParameterExists) {
        	usage();
        }
        
        String[] vlcParameter = new String[] { 
        		"--plugin-path="+vlcPluginPath,
        		"--no-audio",
        		vlcVerbose,
        		vlcVout,
        		vlcSnapshotPreview,
        		"--no-overlay",
        		vlcCrop
        };
                
        System.out.println("## init jvlc");
        JVLC jvlc = new JVLC(vlcParameter);
        MediaDescriptor mediaDescriptor = new MediaDescriptor(jvlc, media);
        MediaPlayer mp = mediaDescriptor.getMediaPlayer();
        
        System.out.println("## play file");
        mp.play();
        int retry=0;
        //wait till player is ready
        while (!mp.isPlaying()) {
        	Thread.sleep(250);
        	retry++;
        	if (retry>12) {
        		System.out.println("Error, could not play file");
        		System.exit(-1);
        	}
        }
        
        System.out.println("## get snapshots ("+picsPerMovie+")");
        mp.pause();
        Video vid = new Video(jvlc);
        float timeStep=1f/picsPerMovie;
        for (int n=0; n<picsPerMovie; n++) {            
            mp.setPosition(n*timeStep);
            Thread.sleep(500);
            mp.pause();          	          	        
          	while (mp.getPosition() != n*timeStep) {
          		System.out.println("pos failed ("+n+"): setpos:"+n*timeStep+", actualpos:"+mp.getPosition());          		
          		mp.setPosition(n*timeStep);          		
          		mp.pause();
          	}        	        	
          	vid.getSnapshot(mp, snapshotDir+snapshotPrefix+(n+100000)+".png", snapshotSize, snapshotSize);
  		}
        
        System.out.println("## done");
        mp.stop();
        mediaDescriptor.release();
	}

}
